@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20111130';
+our $VERSION = '0.20111228';
 
-# Table last modified: 2011-11-30
+# Table last modified: 2011-12-28
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -24,7 +24,7 @@ our %ZIP_TABLE = (
     '017' => '(?:(?:8(?:5(?:10|67|85|5[05])|686)|029[23]))',
     '018' => '(?:(?:1(?:39[23]|59[56]|79[23]|692)|3(?:59[2356]|39[23]|192)|4(?:39[2-5]|69[23]|494)|0(?:49[23]|[16]92|795)|5(?:79[23]|292)|2498))',
     '019' => '(?:(?:1(?:397|692)|079[23]|2[16]92))',
-    '020' => '(?:(?:8(?:5(?:3[0-3]|8[04-68]|0[12578]|1[0-358]|2[0-25]|6[0167]|7[0357]|4[034]|5[013578])|6(?:33|41|5[045]|7[278]|2[02]|6[167]|1[0-2]|8[68]|0[1256])|794)|0(?:1(?:9[23568]|8[0-578])|59[2356]|49[356])))',
+    '020' => '(?:(?:8(?:5(?:2[0-35]|3[0-3]|8[04-68]|0[12578]|1[0-358]|6[0167]|7[0357]|4[034]|5[013578])|6(?:33|41|5[045]|7[278]|2[02]|6[167]|1[0-2]|8[68]|0[1256])|794)|0(?:1(?:9[23568]|8[0-578])|59[2356]|49[356])))',
     '021' => '(?:8(?:5(?:11|44|55|77|0[1-46]|6[67])|6(?:04|11|33|87)))',
     '022' => '(?:8(?:5(?:12|0[1-578])|602))',
     '023' => '(?:(?:049[23]|850[12]|1192))',
@@ -67,7 +67,7 @@ our %ZIP_TABLE = (
     '061' => '(?:(?:1(?:49[236-8]|19[2356]|39[2356])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292))',
     '062' => '(?:8(?:6(?:55|86|0[1-357-9]|3[0135]|2[24]|4[12]|1[0278]|6[68])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
     '063' => '(?:8(?:5(?:58|0[17]|[18][05])|6(?:41|0[1-36-8]|1[12])))',
-    '064' => '(?:8(?:5(?:1[0-2569]|6[0-7]|2[0-68]|7[0157]|5[0-24-8]|3[0235-7]|0[1-3569]|8[14-79]|4[0-6])|6(?:68|86|2[0-2489]|0[159]|1[01]|4[124589]|3[039])|798))',
+    '064' => '(?:8(?:5(?:1[0-2569]|6[0-7]|2[0-68]|7[0157]|5[0-24-8]|3[0235-7]|0[1-3569]|8[14-79]|4[0-6])|6(?:86|2[0-2489]|0[159]|1[01]|4[124589]|3[039])|798))',
     '065' => '(?:8(?:5(?:[34]3|22|67|78|1[018]|5[058]|0[18])|6(?:86|3[39]|0[19]|1[0-2])))',
     '066' => '(?:8(?:5(?:20|33|1[025]|7[07]|6[67]|8[58]|5[0578]|0[1248])|6(?:01|22|49|55|86|3[379]|6[068]|1[01])|7(?:11|65|87)))',
     '067' => '(?:8(?:5(?:[05]1|47|85|6[45])|674))',
@@ -108,10 +108,10 @@ our %ZIP_TABLE = (
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|7[0478]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578]|0[2-68])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|7[0237]|5[035-7]|6[248]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|1[125689])|79[58]))',
     '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-256]|3[0-57-9]|1[0-79]|8[01467]|5[016]|4[3489])|2(?:3\d|0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|7[02358]|8[457]|2[124589]|5[0-25689])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|4[0468]|3[03589]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|2[01458]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|7[07]|6[026]|8[0-24589])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:3[24-79]|0[124578]|8[02-8]|1[0-24-689]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|0[57-9]|5[02-8]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:55|0[12578]|7[07]|8[58]|1[0-2])|3(?:01|22|33|1[0-3])|7(?:0[127]|1[1267]))|7444))',
+    '105' => '(?:(?:8(?:4(?:3[2-79]|0[124578]|8[02-8]|1[0-24-689]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|0[57-9]|5[02-8]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:55|0[12578]|7[07]|8[58]|1[0-2])|3(?:01|22|33|1[0-3])|7(?:0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|3[25]|1[458]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069]|4[0-24589])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:5(?:8[13589]|2[0-24578]|5[0-26-8]|4[356]|3[023]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|6[78]|2[023578]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:20|34|56|77|0[134]|8[24]|6[067]|1[04679]|4[08])|3(?:55|4[028]|7[013]|2[0346]|3[01568]|8[08])|0(?:06|77)))',
-    '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|6[124-8]|4[03-578]|5[0-35-9]|0[1-3569]|2[035]|1[0258]|8[013568])|3(?:3[13489]|1[137]|6[0168]|0[357]|8[0134689]|7[0-37-9]|5[0158]|4[15]|2[0-35689])|4(?:0[347]|8[45]|6[67]|5[16]|7[478]|2[013-5]|3[029]|1[0-24-7]|4[48])|2(?:7[05-8]|4[128]|8[02]|0[1-38]|3[0-4]|5[05]|1[01]|2[0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
+    '107' => '(?:8(?:5(?:8[13589]|2[0-24578]|5[0-26-8]|4[356]|3[023]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|6[78]|2[023578]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:20|34|56|77|0[134]|1[014679]|8[24]|6[067]|4[08])|3(?:55|60|4[028]|7[013]|2[0346]|3[01568]|8[08])|0(?:06|77)))',
+    '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|0[1-35-79]|6[124-8]|4[03-578]|5[0-35-9]|2[035]|1[0258]|8[013568])|3(?:3[13489]|1[137]|6[0168]|0[357]|8[0134689]|7[0-37-9]|5[0158]|4[15]|2[0-35689])|4(?:0[347]|8[45]|6[67]|5[16]|7[478]|2[013-5]|3[029]|1[0-24-7]|4[48])|2(?:7[05-8]|4[128]|8[02]|0[1-38]|3[0-4]|5[05]|1[01]|2[0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|5[03589]|4[0134689]|0[1-357-9]|7[35-9]|3[0-79]|1[0-3578]|2[0-478]|8[02-468])|6(?:97|0[2359]|2[0-24-68]|6[0-259]|5[34]|4[245]|1[03-57-9]|3[058]|7[135-8]|8[015-8])|7(?:8[027]|5[057]|1[2-6]|0[168]|4[05]|3[36]|2[1-35])|80[78]|408))',
     '111' => '(?:8(?:6(?:3[01379]|5[056]|[12][0-258]|7[6-8]|8[1368]|4[02]|0[2568]|6[16])|5(?:43|1[0-258]|8[058]|5[568]|3[0-49]|7[57]|6[0167]|2[125]|0[125-8])|7(?:[56]5|[89]8|21|0[178]|1[01])|081))',
@@ -134,9 +134,9 @@ our %ZIP_TABLE = (
     '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|50|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:[89]0|7[1-36]|4[0-37-9]|3[013689]|6[0367]|2[013569]|0[125-8]|5[0-28]|1[1256])|6(?:4[04]|0[17]|6[0168]|1[13-79]|7[0578]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
-    '141' => '(?:8(?:6(?:3[0137-9]|2[01389]|4[0-36-8]|0[2-6]|7[0-36]|1[01568]|8[0136-8]|5[035-8]|6[024-68])|5(?:2[0-2569]|0[13-578]|4[045]|1[024579]|3[03-5]|5[05-79]|6[015-8]|7[1256]|8[02-68])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
+    '141' => '(?:8(?:6(?:3[0137-9]|2[01389]|4[0-36-8]|0[2-6]|7[0-36]|1[01568]|8[0136-8]|5[035-8]|6[024-68])|5(?:2[0-2569]|4[04]|0[13-578]|8[02-58]|1[024579]|3[03-5]|5[05-79]|6[015-8]|7[1256])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
     '142' => '(?:8(?:5(?:[01]1|22|33|40|67|5[058]|8[58])|6(?:11|39|66)))',
-    '143' => '(?:(?:85(?:28|70|3[13589]|8[05]|6[04578]|0[4-8]|4[014]|5[0258]|1[145])|6501))',
+    '143' => '(?:(?:85(?:28|70|3[13589]|0[24-8]|8[05]|6[04578]|4[014]|5[0258]|1[145])|6501))',
     '144' => '(?:8(?:5(?:25|44|5[015]|3[0-356]|7[057]|1[01356]|8[08]|0[56])|6(?:02|35|2[1-3]|5[056]|7[78]|1[014]|6[01])))',
     '145' => '(?:85(?:[23]3|01|58|66|1[15]))',
     '146' => '(?:8(?:5(?:[03]1|22|67|8[058]|7[67]|1[0-2]|5[15]|4[034])|6(?:[03]1|10|2[03]|5[056]|7[78]|6[68])))',
@@ -203,7 +203,7 @@ our %ZIP_TABLE = (
     '215' => '(?:85(?:[36]0|09|42|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:85(?:[56]6|22|70|1[0-249]|0[125]))',
     '220' => '(?:8(?:5(?:58|77|1[015]|3[69]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:8[06]|0[149]|1[1-6]|2[02]|7[48]|6[08])|080))',
-    '221' => '(?:8(?:5(?:[46]0|37|88|2[0238]|1[17]|5[058])|7(?:12|41|65|0[1-35])|6(?:11|23|66|8[68])))',
+    '221' => '(?:8(?:5(?:[46]0|37|88|1[17]|5[058]|2[023])|7(?:12|41|65|0[1-35])|6(?:11|23|66|8[68])))',
     '222' => '(?:8(?:5(?:77|3[03]|8[056]|6[1-6]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
     '223' => '(?:8(?:5(?:1[025]|2[0-356]|[58][058]|7[27]|6[067]|4[0-2]|0[125-8]|3[039])|68[67]))',
     '224' => '(?:8(?:5(?:10|78|8[05]|0[1-5]|5[01]|3[039]|2[024])|68[68]|730))',
@@ -226,7 +226,7 @@ our %ZIP_TABLE = (
     '244' => '(?:8(?:5(?:10|0[1-3]|6[69]|7[17]|2[28]|5[058]|8[589]|3[039])|601))',
     '245' => '(?:85(?:[16]0|01|42|89|5[0358]|7[57]))',
     '246' => '(?:85(?:20|5[06]))',
-    '247' => '(?:8(?:5(?:[135]0|77|88)|686))',
+    '247' => '(?:8(?:5(?:[135]0|77|88)|6(?:30|86)|730))',
     '248' => '(?:8(?:55[58]|686))',
     '249' => '(?:8(?:510|686))',
     '250' => '(?:(?:0(?:2(?:80|9[2-68])|39[28]|[15]92)|85(?:11|55|88)))',
@@ -323,7 +323,7 @@ our %ZIP_TABLE = (
     '347' => '(?:(?:85(?:67|85|0[1-4]|1[03]|5[05])|019[25]))',
     '348' => '(?:8(?:5(?:[25]5|30|1[23]|4[09]|0[135-7])|601))',
     '349' => '(?:(?:0(?:19[23568]|29[2-4])|1(?:19[23]|292)))',
-    '350' => '(?:(?:0(?:2(?:9[25]|8[02-9])|39[2-6]|49[3-6]|19[237])|1(?:3(?:9[28]|8[08])|1(?:81|9[26-8])|29[25-8])|8(?:5(?:[13]1|8[58]|5[05]|0[18])|6(?:01|66))|22(?:92|8[0178])))',
+    '350' => '(?:(?:0(?:2(?:9[25]|8[02-9])|39[2-6]|49[3-6]|19[237])|1(?:3(?:9[28]|8[08])|1(?:81|9[26-8])|29[25-8])|8(?:5(?:31|8[58]|5[05]|0[18]|1[01])|6(?:01|66))|22(?:92|8[0178])))',
     '351' => '(?:(?:8(?:5(?:[26]0|51|0[18]|1[01]|8[56])|601)|01(?:88|9[2-46-8])))',
     '352' => '(?:8(?:5(?:01|10|23|49|8[89]|7[27]|5[58])|6(?:23|66)))',
     '353' => '(?:85(?:01|55))',
@@ -346,7 +346,7 @@ our %ZIP_TABLE = (
     '370' => '(?:(?:8(?:5(?:[01]1|22|43|65|3[17]|8[58]|5[05])|6(?:[01]1|22|86|6[68]))|1(?:39[2-6]|19[2356]|29[235]|592)|0(?:59[568]|49[25]|193|692|795)|2(?:39[23568]|49[58]|[12]92)|3(?:59[2-4]|[146]92|39[23])))',
     '371' => '(?:(?:8(?:5(?:43|67|70|85|0[1-578]|2[25]|1[0-467]|5[01])|6(?:[01]1|[68]6|40))|0(?:192|294)))',
     '372' => '(?:8(?:5(?:58|67|8[058]|0[128])|686))',
-    '373' => '(?:8(?:5(?:21|40|78|0[1589]|1[0135]|8[58]|5[0157]|3[01]|6[017])|6(?:01|22|6[06]|3[09]|8[68]|1[01])))',
+    '373' => '(?:8(?:5(?:21|40|78|0[1589]|1[0135]|8[58]|5[0157]|3[01]|6[017])|6(?:01|22|6[06]|3[09]|8[68]|1[01])|718))',
     '374' => '(?:(?:8(?:5(?:01|33|55|77|88|2[01]|1[0-28])|6(?:11|22|40|86|0[18]))|019[23]))',
     '375' => '(?:8(?:50[1-6]|60[1-4]))',
     '376' => '(?:(?:8(?:5(?:31|0[1-3]|1[056]|2[38]|[58][58])|6(?:86|6[68]))|0(?:19[2-4]|39[27])))',
@@ -415,7 +415,7 @@ our %ZIP_TABLE = (
     '441' => '(?:(?:8(?:5(?:6[06]|2[025]|5[058]|7[07]|8[08]|0[1-37]|1[0-2579]|4[035]|3[039])|6[68]6)|0(?:19[3-5]|29[25]|39[23])|3(?:19[2-6]|492|695)|1(?:29[2-5]|[346]92)))',
     '442' => '(?:8(?:5(?:20|58|3[0-358]|0[1-35-79]|6[169]|1[0-35-8]|8[0-25-8]|7[35-7]|9[01]|4[013-6])|60[1-3]))',
     '443' => '(?:(?:8(?:5(?:55|88)|6[01]1)|019[2-4]))',
-    '444' => '(?:(?:8(?:5(?:77|3[03]|6[047]|1[0-267]|0[178]|8[1568]|2[02]|4[235]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[2-4]|89[23])))',
+    '444' => '(?:(?:8(?:5(?:77|3[03]|0[1378]|6[047]|1[0-267]|8[1568]|2[02]|4[235]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[2-4]|89[23])))',
     '445' => '(?:8(?:5(?:85|1[01]|0[1-35])|60[12]))',
     '446' => '(?:8(?:5(?:40|1[12478]|3[35]|0[1-8]|[58][58]|2[02-6])|6(?:35|41|86|0[12])))',
     '447' => '(?:8(?:5(?:0[1-35-7]|1[0-2])|6(?:[18]0|0[1358])))',
@@ -474,7 +474,7 @@ our %ZIP_TABLE = (
     '502' => '(?:8(?:5(?:[0-2]1|58|67)|792))',
     '503' => '(?:(?:8(?:5(?:5[02-46-9]|1\d|2[0-3]|0[1-9]|7[01]|6[0-24-9])|60[134])|0(?:19[258]|29[256]|[46]95|392)|2(?:39[2-7]|49[2-5]|19[23])|1(?:39[2-6]|59[235])))',
     '504' => '(?:8(?:5(?:[48]5|11|0[14]|5[15])|7(?:10|0[12])|6(?:01|42)))',
-    '505' => '(?:(?:8(?:50[1358]|606)|0392))',
+    '505' => '(?:(?:8(?:5(?:10|0[1358])|606)|0392))',
     '506' => '(?:(?:8(?:6(?:66|78|0[13]|8[6-8])|5(?:77|85|0[26]|5[05]))|1(?:49[23568]|19[56]|392)|019[24]|2192))',
     '507' => '(?:8(?:5(?:[16]1|33|2[237])|6(?:50|0[1-3578])|70[1-3568]))',
     '508' => '(?:(?:8(?:5(?:[58]5|11|0[0-2])|6(?:[68]6|11))|0(?:292|494)))',
@@ -485,7 +485,7 @@ our %ZIP_TABLE = (
     '513' => '(?:8(?:6(?:[57]0|01|8[06]|3[0-3]|6[016])|5(?:[1-3]0|0[15])|701))',
     '514' => '(?:(?:8(?:5(?:4[0356]|3[0-38]|2[01468]|8[568]|7[01578]|5[02358]|1[1-58]|0[1-3578]|6[06-8])|6(?:[01]1|[68]6|3[35]))|2(?:39[23568]|29[2-4]|192)|1(?:29[2-7]|19[25])|039[235-7]))',
     '515' => '(?:(?:8(?:5(?:77|3[03]|2[25]|8[568]|6[67]|1[0135]|5[0578]|0[1359])|688)|2(?:69[23]|592)|059[2568]))',
-    '516' => '(?:(?:8(?:5(?:20|77|5[0-58]|1[1568]|4[3-9]|6[67]|8[18]|0[1-35])|6(?:86|0[12]))|1(?:19[2568]|492)|019[2-48]|2195))',
+    '516' => '(?:(?:8(?:5(?:20|77|5[0-58]|4[3-9]|6[67]|1[12568]|8[18]|0[1-35])|6(?:86|0[12]))|1(?:19[2568]|492)|019[2-48]|2195))',
     '517' => '(?:(?:0(?:59[23]|292|494)|85(?:01|1[17])))',
     '518' => '(?:(?:0(?:49[2-68]|29[2-6]|192)|85(?:01|18|33)))',
     '519' => '(?:(?:0(?:19[35-8]|49[2357]|59[2-5]|292|393|696)|2(?:59[23]|[17]92)|3(?:69[2-6]|492)|439[2-6]|529[23]|1192))',
@@ -499,7 +499,7 @@ our %ZIP_TABLE = (
     '527' => '(?:(?:8(?:5(?:[27]7|42|8[058]|6[67]|1[12]|5[0458]|0[589])|687)|0195))',
     '528' => '(?:8(?:5(?:[58]5|0[12]|1[01])|666))',
     '529' => '(?:(?:1(?:3(?:93|8[0-368])|59[2578]|49[235]|69[28]|195|892)|0(?:49[238]|[27]92)))',
-    '530' => '(?:8(?:2(?:6[26]|1[0-25-7]|8[128]|2[27]|5[12]|4[157]|7[08]|0[13-6]|3[049])|5(?:01|35|44|2[1-3]|6[5-7]|5[1568]|7[45]|8[02368]|1[1-37])|3(?:18|2[34]|8[389]|4[16]|5[05]|[03][48])|6(?:1[018]|0[12]|8[08])|4(?:75|1[015]|4[18])|79[136-8]))',
+    '530' => '(?:8(?:2(?:6[26]|1[0-25-7]|8[128]|5[12]|4[157]|7[08]|2[267]|0[13-6]|3[049])|5(?:01|35|44|2[1-3]|6[5-7]|5[1568]|7[45]|8[02368]|1[1-37])|3(?:18|2[34]|8[389]|4[16]|5[05]|[03][48])|6(?:1[018]|0[12]|8[08])|4(?:75|1[015]|4[18])|79[136-8]))',
     '531' => '(?:8(?:5(?:11|67|0[1-3]|5[58])|787))',
     '532' => '(?:8(?:5(?:[38]5|60|77|2[045]|0[1578]|5[0258]|1[145])|680))',
     '533' => '(?:8(?:5(?:33|85|5[58]|0[12])|651))',
@@ -521,7 +521,7 @@ our %ZIP_TABLE = (
     '550' => '(?:8(?:5(?:38|6[67]|2[27]|8[05]|7[0578]|5[0258]|0[1-35])|6(?:59|60)))',
     '551' => '(?:85[05]1)',
     '552' => '(?:85(?:01|10))',
-    '553' => '(?:8(?:5(?:01|67|85|1[1-3]|5[03])|739))',
+    '553' => '(?:8(?:5(?:01|67|1[1-3]|5[03]|8[58])|739))',
     '554' => '(?:85(?:[01]1|88|5[58]))',
     '555' => '(?:85(?:55|0[12]))',
     '556' => '(?:8(?:5(?:01|85|5[058]|1[0256])|6(?:01|70|6[03-6])))',
@@ -601,7 +601,7 @@ our %ZIP_TABLE = (
     '636' => '(?:(?:0(?:29[2-58]|19[238]|39[238])|8(?:5(?:[358]5|11|0[13])|798)))',
     '637' => '(?:85[01]1)',
     '638' => '(?:(?:85(?:[02]1|10)|0[23]92))',
-    '639' => '(?:(?:1(?:0(?:8[0-259]|9[35])|1(?:9[26-8]|8[368]))|2(?:19[578]|29[258])|3(?:192|594)|029[238]))',
+    '639' => '(?:(?:1(?:1(?:9[26-8]|8[3468])|0(?:8[0-259]|9[35]))|2(?:19[578]|29[258])|3(?:192|594)|029[238]))',
     '640' => '(?:(?:8(?:5(?:6[04-7]|7[057]|3[356]|4[04-6]|5[0-25-8]|0[1-3578]|2[0245]|1[0-69]|8[0-2589])|6(?:8[67]|6[68]|5[1-79])|787)|119[26]|0492))',
     '641' => '(?:8(?:5(?:0[189]|1[01])|770))',
     '642' => '(?:8501)',
@@ -655,7 +655,7 @@ our %ZIP_TABLE = (
     '694' => '(?:8501)',
     '695' => '(?:85(?:77|85|0[125]))',
     '696' => '(?:(?:0(?:19[2358]|393|692)|8510))',
-    '697' => '(?:(?:8(?:5(?:01|85|1[12])|686)|0492))',
+    '697' => '(?:(?:8(?:5(?:01|85|1[12])|686|789)|0492))',
     '698' => '(?:(?:8(?:50[13-5]|65[01])|0292))',
     '699' => '(?:(?:0(?:5(?:88|9[23])|19[235]|29[23]|49[26]|69[67]|792)|1(?:39[2-6]|29[23]|592|898)|4(?:29[28]|692)|5(?:292|695)|2598))',
     '700' => '(?:8(?:5(?:4[04-69]|0[2-7]|7[0-2578]|3[024589]|5[014-8]|8[015689]|2[2578]|6[0-289]|1[125-9])|6(?:60|86|7[378]|2[01358]|0[13-8]|4[05]|5[57]|3[459]|1[013-9])|7(?:0[167]|2[27]|3[1-48])))',
